@@ -144,6 +144,54 @@ class AppView(BrowserView):
 		return self.tag(item, scale=scale)
 	else:
 	    return self.tag(item, scale=scale)
+	
+    def getMediaWithVideoPriority(self, item, scale="large"):
+	""" finds and returns relevant leading media for the context item
+	"""
+	if item.portal_type == 'Image':
+	    return item.absolute_url() + '/image_%s'%scale
+	
+	catalog = getToolByName(self.context, 'portal_catalog')
+	plone_utils = getToolByName(self.context, 'plone_utils')
+	path = '/'.join(item.getPhysicalPath())
+	
+	if plone_utils.isStructuralFolder(item):
+	    linkResults = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Link'], sort_on = 'getObjPositionInParent')
+	    results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Image'], sort_on = 'getObjPositionInParent')
+	    
+	    if len(linkResults) > 0:
+		for link in linkResults:
+		    youtubeThumb = self.getYoutubeThumb(link)
+		    if youtubeThumb is not None:
+			return youtubeThumb
+	    
+	    if len(results) > 0:
+		leadMedia = results[0]
+		if leadMedia.portal_type == 'Image':
+		    return leadMedia.getURL() + '/image_%s'%scale
+		else:
+		    return self.tag(item, scale=scale)
+	    else:
+		return self.tag(item, scale=scale)
+	else:
+	    return self.tag(item, scale=scale)
+    
+    def getYoutubeThumb(self, item):
+	if self.isYoutube(item.getObject()):
+	    if item.getRemoteUrl.find("v=") != -1:
+		result = "http://img.youtube.com/vi/%s/0.jpg"%item.getRemoteUrl[item.getRemoteUrl.find("v=") + 2:].replace('%20', '')
+		imgtag = '<img src="%s" alt="" class="tileImage videolead uid_%s"/><img class="leadplaybutton" src="++resource++plonetheme.porseleinplaats.images/leadplaybutton.png">'%(result, item.UID)
+		return imgtag
+	    else:
+		return None
+	else:
+	    return None
+	
+    def isYoutube(self, item):
+	if item.portal_type == "Link" and item.getRemoteUrl().find("youtube.") != -1:
+	    return True
+	else:
+	    return False
     
     def isVideo(self, item):
 	if FLOWPLAYER_EXISTS:
