@@ -306,7 +306,7 @@ PorseleinApp.fixHeight = function ()
     else
     {
         $(".scroll").css('height', height + "px");
-        $(".scroll").css('height', "0px");
+        $(".scroll").css('padding-top', "0px");
     }
     
     if ($("body.template_home").length == 1)
